OC.L10N.register(
    "core",
    {
    "Please select a file." : "請選取一個檔案",
    "File is too big" : "檔案太大",
    "The selected file is not an image." : "選取的檔案不是圖片檔",
    "The selected file cannot be read." : "選取的檔案無法讀取",
    "The file was uploaded" : "檔案已上傳",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The file was only partially uploaded" : "檔案僅部份上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Could not write file to disk" : "無法寫入硬碟",
    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
    "Invalid file provided" : "提供的檔案無效",
    "No image or file provided" : "未提供圖片或檔案",
    "Unknown filetype" : "未知的檔案類型",
    "An error occurred. Please contact your admin." : "發生錯誤，請聯絡管理員。",
    "Invalid image" : "圖片無效",
    "No temporary profile picture available, try again" : "沒有臨時用的大頭貼，請再試一次",
    "No crop data provided" : "未設定剪裁",
    "No valid crop data provided" : "未提供有效的剪裁設定",
    "Crop is not square" : "剪裁設定不是正方形",
    "State token does not match" : "狀態權杖不相符",
    "Invalid app password" : "無效的應用程式密碼",
    "Could not complete login" : "嘗試登入時發生錯誤",
    "State token missing" : "狀態權杖遺失",
    "Your login token is invalid or has expired" : "您的登入權杖無效或已過期",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "不支援 Nextcloud 的這個社群版本，且推播通知有所限制。",
    "Login" : "登入",
    "Please try again" : "請再試一次",
    "Password reset is disabled" : "密碼重設已停用",
    "Could not reset password because the token is expired" : "無法重設密碼，因為權杖已過期",
    "Could not reset password because the token is invalid" : "無法重設密碼，因為權杖無效",
    "Password is too long. Maximum allowed length is 469 characters." : "密碼太長。最大允許長度為 469 個字元。",
    "%s password reset" : "%s 密碼重設",
    "Password reset" : "密碼重設",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "點選下方的按鈕來重設您的密碼。若您沒有要求重設密碼，請忽略這封信件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "點取下方的連結以重設您的密碼。 如果您沒有要求重設密碼的話，請忽略這封信件。",
    "Reset your password" : "重設密碼",
    "No translation provider available" : "沒有可用的翻譯提供者",
    "Could not detect language" : "無法偵測語言",
    "Unable to translate" : "無法翻譯",
    "Nextcloud Server" : "Nextcloud 伺服器",
    "Some of your link shares have been removed" : "部分分享連結己被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由於安全性問題，我們必須移除您一部分的連結分享。查看更多資訊請點選連結。",
    "The user limit of this instance is reached." : "已達此站台的使用者數量上限。",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支援應用程式中輸入您的訂閱金鑰以增加使用者限制。這也確實為您提供了 Nextcloud Enterprise 提供的所有額外好處，並且強烈推薦用於公司的營運。",
    "Learn more ↗" : "取得更多資訊 ↗",
    "Preparing update" : "準備更新",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "修復步驟：",
    "Repair info:" : "修復資訊：",
    "Repair warning:" : "修復警告：",
    "Repair error:" : "修復錯誤：",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。",
    "Turned on maintenance mode" : "啟用維護模式",
    "Turned off maintenance mode" : "停用維護模式",
    "Maintenance mode is kept active" : "伺服器正處於維護模式",
    "Updating database schema" : "正在更新資料庫格式",
    "Updated database" : "已更新資料庫",
    "Update app \"%s\" from App Store" : "從應用程式商店更新應用程式「%s」",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "檢查 %s 是否有可更新的資料庫格式（若資料庫較大，可能需要一段時間）",
    "Updated \"%1$s\" to %2$s" : "已從 %1$s 更新至 %2$s",
    "Set log level to debug" : "設定記錄至除錯層級",
    "Reset log level" : "重設記錄層級",
    "Starting code integrity check" : "開始檢查程式碼完整性",
    "Finished code integrity check" : "已完成程式碼完整性檢查",
    "%s (incompatible)" : "%s （不相容）",
    "The following apps have been disabled: %s" : "以下應用程式已經被停用：%s",
    "Already up to date" : "此版本為最新版本",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAV 介面似乎為故障狀態，導致您的網頁伺服器無法提供檔案同步功能。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "您的網頁伺服器設定不正確，因此無法解析「{url}」。更多資訊可在{linkstart}文件 ↗{linkend}中找到。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的伺服器並未正確的設定解析「{url}」。這可能與伺服器的設定未更新為直接傳送此資料夾有關。請檢查 Apache 的 \".htaccess\" 檔案，或在 Nginx 中的{linkstart}文件頁面 ↗{linkend}中查閱重寫規則。在 Nginx 環境中，通常是在由 \"location ~\" 開始的那行需要做調整。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "您的伺服器並未正確的設定，因此無法傳遞 .woff2 的檔案。這通常是因為 Nginx 的設定問題所導致。在 Nextcloud 15 中，需要一些調整才能一並傳遞  .woff2 的檔案。請檢查您的 Nginx 設定，和 Nextcloud {linkstart}說明文件 ↗{linkend}中提到的建議設定。",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 設定似乎不完整，導致無法正確取得系統環境變數，因為偵測到 getenv(\"PATH\") 回傳資料為空值",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "請參考{linkstart}安裝文件 ↗{linkend}中 PHP 設定的註記，並檢查您伺服器上的 PHP 設定，特別是如果您是使用 php-fpm 的情況下。",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "「唯讀設定檔」已經啟用，這樣可以防止來自網頁端的設定操作，每次需要更改設定時，都需要手動將設定檔暫時改為可讀寫。",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未設定或驗證您的電子郵件伺服器設定。請前往{mailSettingsStart}基本設定{mailSettingsEnd}進行設定。然後使用表單下方的「傳送電子郵件」按鈕來驗證您的設定。",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "您的資料庫並未使用 \"READ COMMITTED\" 的交易隔離等級。當有多個行為平行進行時，這可能會造成問題。",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未偵測到 PHP 模組 \"fileinfo\"。強烈建議啟用這個模組，以取得最好的 MIME 檔案類型偵測支援。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "事務型文件鎖定的功能已經取消，這可能會造成競態條件，請在 config.php 中啟用 \"filelocking.enabled\" 以避免出現這樣的問題，請參考{linkstart}文件 ↗{linkend}來了解更多的資訊。",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "請確定將 config.php 檔案中的 \"overwrite.cli.url\" 選項設定為您的使用者主要用於存取此 Nextcloud 的 URL。建議：\"{suggestedOverwriteCliURL}\"。否則，透過 cron 產生的 URL 可能會出現問題。（不過，建議的 URL 可能不是您的使用者主要用於存取此 Nextcloud 的 URL。最好是仔細檢查以防萬一。）",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "你並未設定手機國際冠碼。設定後使用者在個人檔案設定手機號碼時不必再輸入國際冠碼。若要這樣做，請新增「default_phone_region」於設定檔，允許的國家及地區請參閱 {linkstart}ISO 3166-1 code ↗{linkend} 清單。",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : " 無法透過 CLI 來執行排程工作，發生以下技術性錯誤：",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "上次背景工作是於 {relativeTime} 前執行，似乎很久沒有執行了，有點問題。{linkstart}請檢查背景工作設定 ↗{linkend}。",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被限制，以避免我們的免費服務負載過重。請至 {linkstart}nextcloud.com/enterprise{linkend} 取得更多關於 Nextcloud 企業版的資訊。",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此伺服器沒有網際網路連線（無法與多個端點取得聯繫），有些功能，像是外部儲存、應用程式更新版通知將無法運作。從遠端存取資料或是寄送電子郵件通知可能也無法運作。建議您設定好網際網路連線以使用所有功能。",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "您沒有設定記憶體快取，如果可以，請設定 memcache 來提升效能。更多資訊請查閱{linkstart}文件 ↗{linkend}。",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP 無法取得合適的亂數產生源。為了安全性考量，不建議如此做。更多資訊參考{linkstart}文件 ↗{linkend}。",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "您目前正執行 PHP {version} ，我們建議您升級 PHP 到您的散佈版所支援的最新版本，以取得 {linkstart}PHP 開發團隊提供的效能與安全性更新 ↗{linkend}。",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "偵測到您的反向代理標頭設定不正確，但也有可能是因為您目前正透過信任的代理伺服器存取 Nextcloud。若您目前不是透過信任的代理伺服器存取 Nextcloud，這就是一個安全性問題，允許攻擊者對 Nextcloud 假冒 IP 位址。更多資訊請查閱{linkstart}文件 ↗{linkend}。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached是用於分散式緩存的設置，但是目前安裝了錯誤的PHP模組為「memcache」。\\OC\\Memcache\\Memcached僅支援「memcached」而不是「memcache」。請參閱 {linkstart}memcached wiki了解兩種模組資訊 ↗{linkend}。",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "部份檔案未通過完整性檢查。更多關於如何解決此問題的資訊可在{linkstart1}文件 ↗{linkend}中找到。（{linkstart2}無效檔案列表……{linkend} / {linkstart3}重新掃描……{linkend}）",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache 模組設定不正確。請檢視{linkstart}說明文件 ↗{linkend}以取得更多資訊。",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "無法取得 PHP 中的 \"set_time_limit\" 函式。這可能導致執行過程被終止並造成不完整安裝。我們強烈建議啟用該函式。",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 並未啟用 FreeType 支援，導致大頭貼產生器和設定界面無法使用。",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在資料表 \"{tableName}\" 中，找不到索引值 \"{indexName}\" 。",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "資料庫缺少了某些索引值。由於在一個龐大的表中新增索引需要一些時間，因此它們並不會被自動新增。您可執行 \"occ db:add-missing-indices\" 來手動新增那些缺少的索引值。當索引值新增完成後，查詢的速度通常會變得快許多",
    "Missing primary key on table \"{tableName}\"." : "資料表 \"{tableName}\" 遺失主鍵。",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "資料庫缺少了一些主鍵，然而新增主鍵這個動作將在龐大的表中花費許多時間，因此它們並不會被自動新增。藉由執行 \"occ db:add-missing-primary-keys\" 手動新增主鍵將能在系統持續運作時修復這個問題。",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "資料表 \"{tableName}\" 中的可選欄位 \"{columnName}\" 遺失。",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "資料庫遺失了一些欄位，然而新增欄位這個動作將在龐大的表中花費許多時間，因此它們並不會被自動新增。藉由執行 \"occ db:add-missing-columns\" 手動新增欄位將能在系統持續運作時修復這個問題。新增這些欄位將提高系統回應速度和可用性。",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "您的 Nextcloud 缺少了某些建議的 PHP 模組。為了提升效能與相容性，強烈建議您安裝這些 PHP 模組。",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "雖然已啟用佈景主題應用程式，但並未啟用 PHP 模組「imagick」。為了讓 favicon 產生流程正常運作，您必須安裝並啟用此模組。",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "未啟用 PHP 模組「gmp」與「bcmath」。若您要使用 WebAuthn 免密碼驗證，這些模組就是必要的。",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀關於此問題的{linkstart}文件頁面 ↗{linkend}。",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "系統安裝的 php-imagick 不支援 SVG，為了更好的相容性，建議安裝它。",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "資料庫的有些欄位缺少 big int 格式轉換。因為欄位格式轉換需要一些時間，所以沒有自動轉換。您可以執行 \"occ db:convert-filecache-bigint\" 手動完成轉換，轉換時 Nextcloud 服務必須處於離線狀態。詳情請參閱{linkstart}關於這個問題的文件頁面 ↗{linkend}。",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "目前您的後端資料庫使用 SQLite，在大型服務當中，我們建議您使用其他的資料庫後端。",
    "This is particularly recommended when using the desktop client for file synchronisation." : "若您使用電腦客戶端來同步檔案，非常建議您這麼做。",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "若要轉移至另一個資料庫，請使用命令列工具：\"occ db:convert-type\"，或是查閱{linkstart}文件 ↗{linkend}。",
    "The PHP memory limit is below the recommended value of 512MB." : "目前的 PHP 的記憶體限制設定低於建議值 512MB。",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "某些應用程式的資料夾所有者與網頁伺服器預設使用者不同。這可能是因為您手動安裝了這些應用程式。請檢查以下應用程式資料夾的相關權限：",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "您的 MySQL 資料庫並不支援 4-byte 的字元。為了能處理檔案名稱中，或是註記中的 4-byte 的字元（如表情符號等）。建議您啟用 MySQL 中支援 4-byte 的字元的功能。詳情請見{linkstart}此文件中關於此項目的說明 ↗{linkend}。",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此站台使用 Amazon S3 物件儲存為主要儲存區。上傳檔案會暫存在伺服器，因此建議 PHP 的暫存資料夾最少要有 50 GB 可用容量。請在登錄檔中查閱關於資料夾路徑及可用容量的詳細資訊。要增進效能，請在 php.ini 中變更暫存資料夾位置，或將該資料夾容量增加。",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "此站台的臨時目錄指向一個不存在或無法寫入的目錄。",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "你經由安全的連線存取系統，但系統卻生成了不安全的 URL。這很有可能是因為你使用了反向代理伺服器，但反向代理伺服器的改寫規則並未正常工作，請閱讀{linkstart}關於此問題的文件頁面 ↗{linkend}。",
    "Error occurred while checking server setup" : "檢查伺服器設定時發生錯誤",
    "For more details see the {linkstart}documentation ↗{linkend}." : "更多詳細資訊請見{linkstart}文件 ↗{linkend}。",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的資料目錄和檔案看來可以被公開存取，這表示 .htaccess 設定檔並未生效，我們強烈建議您設定網頁伺服器，拒絕公開存取資料目錄，或者將您的資料目錄移出網頁伺服器根目錄。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不是 \"{expected}\"，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不是 \"{expected}\"，這將讓某些功能無法正常運作，我們建議調整此項設定。",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不包含 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "目前 HTTP 的 \"{header}\" 標頭設定並不是 \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" 或 \"{val5}\"，這將會洩漏一些訊息。{linkstart}請參考 W3C 建議文件 ↗{linkend}。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP \"Strict-Transport-Security\" 標頭並未被設定持續至少{seconds}秒。為了提高安全性，我們在{linkstart}安全建議 ↗{linkend}中有詳述並建議啟用 HSTS。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "您正在透過不安全的 HTTP 存取網站，強烈建議您設定您的伺服器啟用 HTTPS，更多資訊請查閱{linkstart}安全建議 ↗{linkend}。",
    "unknown text" : "未知的文字",
    "Hello world!" : "哈囉，世界！",
    "sunny" : "晴朗的",
    "Hello {name}, the weather is {weather}" : "哈囉 {name}，今天天氣 {weather}",
    "Hello {name}" : "哈囉 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>以下是您的搜尋結果<script>警告(1)</script></strong>",
    "new" : "新",
    "_download %n file_::_download %n files_" : ["下載 %n 個檔案"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些狀況下，離開本頁面可能會導致更新中斷",
    "Update to {version}" : "更新到 {version}",
    "An error occurred." : "發生錯誤",
    "Please reload the page." : "請重新整理頁面",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失敗，檢視<a href=\"{url}\">論壇上的文章</a>來瞭解更多",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "更新不成功。請在 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社群</a>回報此問題。",
    "Continue to {productName}" : "繼續使用 {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功。將在 %n 秒後重新導向至 {productName}。"],
    "More apps" : "更多應用程式",
    "Currently open" : "目前開啟",
    "_{count} notification_::_{count} notifications_" : ["{count} 個通知"],
    "Log in" : "登入",
    "Logging in …" : "正在登入……",
    "Server side authentication failed!" : "伺服器端認證失敗！",
    "Please contact your administrator." : "請聯絡系統管理員",
    "An internal error occurred." : "發生內部錯誤",
    "Please try again or contact your administrator." : "請重試或聯絡系統管理員",
    "Account name or email" : "帳號名稱或電子郵件",
    "Password" : "密碼",
    "Log in to {productName}" : "登入至 {productName}",
    "Wrong username or password." : "錯誤的使用者名稱 或 密碼",
    "User disabled" : "使用者已遭停用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "您的 IP 多次嘗試登入無效。因此下一次登入將會被延時30秒。",
    "Username or email" : "使用者名稱或電子郵件",
    "Your account is not setup for passwordless login." : "你的帳號尚未設定免密碼登入。",
    "Browser not supported" : "不支援的瀏覽器",
    "Passwordless authentication is not supported in your browser." : "無密碼身份驗證不支援你使用的瀏覽器。",
    "Your connection is not secure" : "您的連線不安全",
    "Passwordless authentication is only available over a secure connection." : "無密碼身份驗證僅支援經加密的連線。",
    "Reset password" : "重設密碼",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "若此帳號存在，密碼重設郵件即已寄送至其電子郵件地址。若您未收到，請驗證您的電子郵件地址及/或帳號名稱，並檢查您的垃圾郵件資料夾，或向您的本機管理員求助。",
    "Couldn't send reset email. Please contact your administrator." : "無法寄出重設密碼資訊。請聯絡您的管理員。",
    "Password cannot be changed. Please contact your administrator." : "密碼無法變更。請聯絡您的管理員。",
    "Back to login" : "回到登入畫面",
    "New password" : "新密碼",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "由於您已啟用檔案加密，重設密碼後，您的資料將無法解密。若您不確定繼續與否，請與管理員聯繫。確定要繼續嗎？",
    "I know what I'm doing" : "我知道我在幹嘛",
    "Resetting password" : "重設密碼",
    "Recommended apps" : "推薦的應用程式",
    "Loading apps …" : "正在載入應用程式…",
    "Could not fetch list of apps from the App Store." : "無法從應用程式商店擷取應用程式清單。",
    "Installing apps …" : "正在安裝應用程式…",
    "App download or installation failed" : "應用程式下載或安裝失敗",
    "Cannot install this app because it is not compatible" : "無法安裝此應用程式，因為其不相容",
    "Cannot install this app" : "無法安裝應用程式",
    "Skip" : "跳過",
    "Install recommended apps" : "安裝推薦的應用程式",
    "Schedule work & meetings, synced with all your devices." : "排定工作和會議時間，並與您的所有裝置同步",
    "Keep your colleagues and friends in one place without leaking their private info." : "將您的同事和朋友放在同一處，且不洩漏他們的個人資訊",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "簡潔的電子郵件應用程式，與檔案瀏覽器、通訊錄、行事曆完美整合",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "對話、視訊電話、螢幕分享、線上會議與網路研討會 - 實現於你的瀏覽器與手機應用程式之中。",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "使用 Collabora Online 建置的協作文件、試算表與簡報。",
    "Distraction free note taking app." : "無干擾的筆記應用程式。",
    "Search contacts" : "搜尋聯絡人",
    "Forgot password?" : "忘記密碼？",
    "Log in with a device" : "使用免密碼裝置登入",
    "Back" : "返回",
    "Login form is disabled." : "登入表單已停用。",
    "Edit Profile" : "編輯個人檔案",
    "The headline and about sections will show up here" : "標題與關於部份將在此顯示",
    "You have not added any info yet" : "您尚未新增任何資訊。",
    "{user} has not added any info yet" : "{user} 尚未新增任何資訊。",
    "Error opening the user status modal, try hard refreshing the page" : "開啟使用者狀態模式時發生問題，嘗試重新整理頁面",
    "Search starts once you start typing and results may be reached with the arrow keys" : "一旦您開始輸入，搜尋就會開始，您可以使用方向鍵到達結果",
    "Reset search" : "重置搜尋",
    "Start search" : "開始搜尋",
    "Search for {name} only" : "僅搜尋 {name}",
    "Start typing to search" : "開始輸入以搜尋",
    "Loading more results …" : "正在載入更多結果…",
    "Load more results" : "載入更多結果",
    "Search" : "搜尋",
    "No results for {query}" : "{query} 查詢沒有結果",
    "An error occurred while searching for {type}" : "搜尋 {type} 時發生錯誤",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["請輸入 {minSearchLength} 個或以上字元搜尋"],
    "This browser is not supported" : "不支援此瀏覽器",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "不支援您的瀏覽器。請升級至較新或受支援的版本。",
    "Continue with this unsupported browser" : "繼續使用此不受支援的瀏覽器",
    "Supported versions" : "支援的版本",
    "{name} version {version} and above" : "{name} 的版本 {version} 及更新",
    "Open settings menu" : "開啟設定選單",
    "Settings menu" : "設定選單",
    "Search {types} …" : "搜尋 {types} 中……",
    "Settings" : "設定",
    "Avatar of {fullName}" : "{fullName} 的大頭照",
    "Could not load your contacts" : "無法載入您的聯絡人",
    "Search contacts …" : "搜尋聯絡人……",
    "No contacts found" : "查無聯絡人",
    "Show all contacts …" : "顯示所有聯絡人…",
    "Install the Contacts app" : "安裝「通訊錄」應用程式",
    "Loading your contacts …" : "正在載入聯絡人……",
    "Looking for {term} …" : "搜尋 {term}……",
    "No" : "否",
    "Yes" : "是",
    "No files in here" : "沒有任何檔案",
    "New folder" : "新增資料夾",
    "No more subfolders in here" : "這裡沒有其他子資料夾了",
    "Name" : "姓名",
    "Size" : "大小",
    "Modified" : "已修改",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"。",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 是不允許的檔案類型",
    "{newName} already exists" : "{newName} 已經存在",
    "Choose" : "選擇",
    "Copy" : "複製",
    "Move" : "移動",
    "Error loading file picker template: {error}" : "載入檔案選擇器範本時發生錯誤：{error}",
    "OK" : "OK",
    "Error loading message template: {error}" : "載入訊息範本時發生錯誤：{error}",
    "read-only" : "唯讀",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 個檔案衝突"],
    "One file conflict" : "一個檔案衝突",
    "New Files" : "新檔案",
    "Already existing files" : "已經存在的檔案",
    "Which files do you want to keep?" : "您要保留哪一個檔案？",
    "If you select both versions, the copied file will have a number added to its name." : "如果您同時選擇兩個版本，複製的那個檔案名稱後面會加上編號。",
    "Cancel" : "取消",
    "Continue" : "繼續",
    "(all selected)" : "（已全選）",
    "({count} selected)" : "（已選取 {count} 項）",
    "Error loading file exists template" : "載入已存在的範本時發生錯誤",
    "Show list view" : "顯示清單檢視",
    "Show grid view" : "顯示網格檢視",
    "Pending" : "擱置中",
    "Home" : "家",
    "Copy to {folder}" : "複製到 {folder}",
    "Move to {folder}" : "移動到 {folder}",
    "Saving …" : "儲存中……",
    "Authentication required" : "必須驗證",
    "This action requires you to confirm your password" : "這個動作需要您再次確認密碼",
    "Confirm" : "確認",
    "Failed to authenticate, try again" : "驗證失敗，請再試一次",
    "seconds ago" : "幾秒前",
    "Connection to server lost" : "伺服器連線中斷",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["載入頁面時發生問題，%n 秒後重新整理"],
    "Add to a project" : "新增至專案",
    "Show details" : "顯示細節",
    "Hide details" : "隱藏細節",
    "Rename project" : "重新命名專案",
    "Failed to rename the project" : "重新命名專案失敗",
    "Failed to create a project" : "建立專案失敗",
    "Failed to add the item to the project" : "新增項目至專案時失敗",
    "Connect items to a project to make them easier to find" : "將項目連結到專案以便尋找",
    "Type to search for existing projects" : "搜尋現有專案",
    "New in" : "新加入",
    "View changelog" : "檢視版本更新紀錄",
    "Very weak password" : "密碼安全性極弱",
    "Weak password" : "密碼安全性弱",
    "So-so password" : "密碼安全性普通",
    "Good password" : "密碼安全性佳",
    "Strong password" : "密碼安全性極佳",
    "No action available" : "沒有可用的動作",
    "Error fetching contact actions" : "擷取聯絡人時發生錯誤",
    "Close \"{dialogTitle}\" dialog" : "關閉「{dialogTitle}」對話方塊",
    "Non-existing tag #{tag}" : "不存在的標籤 #{tag}",
    "Restricted" : "受限",
    "Invisible" : "隱藏",
    "Delete" : "刪除",
    "Rename" : "重新命名",
    "Collaborative tags" : "標籤",
    "No tags found" : "查無標籤",
    "Personal" : "個人",
    "Users" : "使用者",
    "Apps" : "應用程式",
    "Admin" : "管理",
    "Help" : "說明",
    "Access forbidden" : "存取被拒",
    "Profile not found" : "找不到個人檔案",
    "The profile does not exist." : "個人檔案不存在。",
    "Back to %s" : "回到 %s",
    "Page not found" : "找不到頁面",
    "The page could not be found on the server." : "無法在伺服器上找到此頁面。",
    "Too many requests" : "太多要求",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "有太多請求來自你的網路，請稍後再試，若你認為這不該發生，請回報系統管理員這項錯誤。",
    "Error" : "錯誤",
    "Previous" : "上一個",
    "Internal Server Error" : "內部伺服器錯誤",
    "The server was unable to complete your request." : "伺服器無法完成你的請求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果此問題重複發生，請寄送技術資訊給管理員。",
    "More details can be found in the server log." : "伺服器記錄檔裡面有更多細節",
    "Technical details" : "技術細節",
    "Remote Address: %s" : "遠端位置：%s",
    "Request ID: %s" : "請求編號：%s",
    "Type: %s" : "類型：%s",
    "Code: %s" : "代碼：%s",
    "Message: %s" : "訊息：%s",
    "File: %s" : "檔案：%s",
    "Line: %s" : "行數：%s",
    "Trace" : "追蹤",
    "Security warning" : "安全性警告",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "您的資料目錄看起來可以被公開存取，因為 .htaccess 設定檔並未生效。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "閱讀<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">說明文件</a>來瞭解如何正確設定您的伺服器",
    "Create an <strong>admin account</strong>" : "新增<strong>管理者帳號</strong>",
    "Username" : "使用者名稱",
    "Show password" : "顯示密碼",
    "Toggle password visibility" : "切換密碼可見度",
    "Storage & database" : "儲存空間和資料庫",
    "Data folder" : "資料儲存位置",
    "Configure the database" : "設定資料庫",
    "Only %s is available." : "剩下 %s 可使用",
    "Install and activate additional PHP modules to choose other database types." : "安裝並啟用相關 PHP 模組來使用其他種資料庫",
    "For more details check out the documentation." : "更多細節詳見說明文件",
    "Database user" : "資料庫使用者",
    "Database password" : "資料庫密碼",
    "Database name" : "資料庫名稱",
    "Database tablespace" : "資料庫資料表空間",
    "Database host" : "資料庫主機",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "請將具體指定連接埠號與主機名稱。（例如：localhost:5432）",
    "Performance warning" : "效能警告",
    "You chose SQLite as database." : "您選擇了 SQLite 作為資料庫",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 只適用於小型或是開發用站台，針對上線服務我們建議使用其他資料庫後端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "若使用桌面版或是手機版客戶端同步檔案，不建議使用 SQLite",
    "Install" : "安裝",
    "Installing …" : "正在安裝……",
    "Need help?" : "需要協助嗎？",
    "See the documentation" : "閱讀說明文件",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "您似乎正在嘗試重新安裝您的 Nextcloud。然而，檔案 CAN_INSTALL 並不在您的 config 目錄中。請在您的 config 目錄中建立 CAN_INSTALL 檔以繼續。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "無法從您的 config 目錄中移除 CAN_INSTALL 檔案。請手動移除他。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "這個應用程式需要啟用 Javascript 才能正常運作，請{linkstart}啟用 Javascript{linkend} 然後重新整理頁面。",
    "Skip to main content" : "跳到主內容",
    "Skip to navigation of app" : "跳到應用程式導覽",
    "Get your own free account" : "取得免費帳號",
    "Go to %s" : "前往 %s",
    "Confirm your password" : "確認密碼",
    "Connect to your account" : "連結您的帳號",
    "Please log in before granting %1$s access to your %2$s account." : "請登入後再授權「%1$s」存取您的 %2$s 帳號",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "若您並未嘗試設定新裝置或應用程式，那麼某人可能正在欺騙您讓他們存取您的資料。在這種情況下，請不要繼續，請聯絡您的系統管理員。",
    "App token" : "應用程式權杖",
    "Grant access" : "允許存取",
    "Alternative log in using app token" : "使用應用程式權杖來登入",
    "Account access" : "帳號存取",
    "Currently logged in as %1$s (%2$s)." : "目前登入為 %1$s（%2$s）。",
    "You are about to grant %1$s access to your %2$s account." : "您將授權「%1$s」存取您的 %2$s 帳號。",
    "Account connected" : "已連結帳號",
    "Your client should now be connected!" : "客戶端應該已完成連線",
    "You can close this window." : "可以關閉此視窗",
    "This share is password-protected" : "此分享受密碼保護",
    "The password is wrong or expired. Please try again or request a new one." : "密碼錯誤或過期。請重試或重新申請。",
    "Please type in your email address to request a temporary password" : "請輸入您的電子郵件地址以申請臨時密碼",
    "Email address" : "電子郵件地址",
    "Password sent!" : "密碼已傳送！",
    "You are not authorized to request a password for this share" : "您無權為此分享請求密碼",
    "Two-factor authentication" : "雙因素驗證",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的帳號已啟用進階安全機制，請選擇一個雙因素驗證方法：",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "無法載入任何一個雙因素認證方法，請聯絡管理員",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "雙因素驗證已被強制要求啟用，您的帳號目前還沒設定。請聯絡管理員。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "雙因素驗證已被強制要求啟用，您的帳號目前還沒設定。請設定您的雙因素驗證。",
    "Set up two-factor authentication" : "設定雙因素驗證",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "雙因素驗證已被強制要求啟用，您的帳號目前還沒設定。請使用一個備用碼來登入或聯絡管理員。",
    "Use backup code" : "使用備用認證碼",
    "Cancel login" : "取消登入",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的帳號已啟用進階安全機制，請選擇一個提供者：",
    "Error while validating your second factor" : "驗證您的第二因素時發生錯誤",
    "Access through untrusted domain" : "經由不可信任的域名存取",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "請聯絡您的管理員。如果您就是管理員，請模仿 config.sample.php 範例編輯 config/config.php 的 \"trusted_domains\" 設定。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "更多關於如何設定的資訊，請見%1$s文件%2$s。",
    "App update required" : "需要更新應用程式",
    "%1$s will be updated to version %2$s" : "%1$s 將會更新至版本 %2$s",
    "The following apps will be updated:" : "將更新以下的 APP：",
    "These incompatible apps will be disabled:" : "將會停用這些不相容的應用程式",
    "The theme %s has been disabled." : "主題 %s 已經被停用",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在繼續之前，請備份資料庫、config 資料夾及 data 資料夾。",
    "Start update" : "開始升級",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "在大型安裝上，為了避免升級請求逾時，你也可以在安裝目錄執行下列指令：",
    "Detailed logs" : "詳細記錄檔",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 users." : "因為您有超過 50 名使用者，服務規模較大，請透過命令列介面更新。",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "由於自動更新功能已在 config.php 檔案中設定停用，請使用命令列更新系統。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "若需要協助，請參閱<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">說明文件</a>",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "若我繼續透過網頁介面更新，我已了解有其風險，若請求逾時可能導致資料遺失，萬一更新失敗，我已準備好備份並知道如何回復運作。",
    "Upgrade via web on my own risk" : "願意承擔風險透過網頁更新",
    "Maintenance mode" : "維護模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "這個 %s 安裝目前處於維護模式，需要一段時間恢復。",
    "This page will refresh itself when the instance is available again." : "安裝恢復可用之後，本頁會自動重新整理",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "若這個訊息持續出現，請聯絡系統管理員",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
    "[%d / %d]: Checking table %s" : "[%d / %d]: 檢查資料表 %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "這是不受支援的 Nextcloud 社群版建置。鑑於此站台的大小，無法保證效能、可靠程度與延展性。推播通知已被停用，以避免我們的免費服務負載過重。請至 nextcloud.com/enterprise 取得更多關於 Nextcloud 企業版的資訊。",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 將是支援 PHP 7.3 的最後一個版本，Nextcloud 24 僅支援 PHP 7.4 以上的 PHP。",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "目前 HTTP 的 \"{header}\" 標頭設定並不包含 \"{expected}\" ，這是一個潛在的安全性和隱私風險，我們建議調整此項設定。",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "重設密碼資訊已寄至您的電子郵件。若您並未收到該信件，請確認您垃圾信箱，或請求管理員協助。",
    "If it is not there ask your local administrator." : "你找的東西不在，請聯絡管理員。",
    "Collaboratively edit office documents." : "協同編輯辦公室文件。",
    "Local document editing back-end used by the Collabora Online app." : "由 Collabora Online 應用程式使用的本機文件編輯後端。",
    "restricted" : "受限",
    "invisible" : "不可見",
    "File not found" : "找不到檔案",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "伺服器上找不到該文件，或許這個分享已經被刪除或是過期了？",
    "More" : "更多",
    "More apps menu" : "更多應用程式選單",
    "Contacts" : "聯絡人",
    "Contacts menu" : "聯絡人選單",
    "Setup two-factor authentication" : "設定雙因素驗證",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "您似乎正在執行 32 位元版本的 PHP。Nextcloud 需要 64 位元才能運作良好。請將您的作業系統與 PHP 升級至 64 位元！要取得更多詳細資訊，請閱讀{linkstart}關於此問題的文件 ↗{linkend}。",
    "Press enter to start searching" : "按 Enter 以開始搜尋",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "因為透過瀏覽器更新的功能已在您的 config.php 中停用，因此請使用命令列更新程式。"
},
"nplurals=1; plural=0;");
